@@ -37,6 +37,14 @@ class Browser(object):
         self.browser = browser
         self.status_report_callback = status_report_callback or default_status_report_callback
 
+    def __del__(self):
+        self.close()
+
+    def close(self):
+        if self.browser:
+            self.browser.quit()
+            self.browser = None
+
     def run(self, context=None):
         logger.info("Browser.run start...")
         context = context or {}
@@ -67,7 +75,8 @@ class Browser(object):
             self.browser = webdriver.PhantomJS()
         elif browser_engine == "chrome":
             chrome_options = Options()
-            chrome_options.add_argument("--headless") 
+            chrome_options.add_argument("--headless")
+            chrome_options.add_argument("--no-sandbox")
             self.browser = webdriver.Chrome(chrome_options=chrome_options)
         elif browser_engine == "firefox":
             self.browser = webdriver.Firefox()
@@ -174,6 +183,7 @@ class Browser(object):
         while True:
             if time.time() - stime >= total:
                 break
+            self._screenshot_counter += 1
             variables = self.get_default_variables(context)
             filename = command_line[PARAM2_COLUMN].format(**variables)
             folder = os.path.dirname(filename) 
@@ -191,7 +201,9 @@ class Browser(object):
         method_attr = "select_{0}".format(method).replace("-", "_")
         method_func = getattr(self, method_attr, None)
         if not method_func:
-            raise RuntimeError("Element selector method not implemented: {}.".format(method))
+            msg = "Element selector method not implemented: {}.".format(method)
+            logger.error(msg)
+            raise RuntimeError(msg)
         targets = method_func(value)
         if not isinstance(targets, (set, tuple, list)):
             return [targets]
