@@ -10,7 +10,7 @@ CMD_STARTING_ROW = 5
 logger = logging.getLogger(__name__)
 
 
-def run_xlsx_config(config_xlsx_path, sheet=None, variables_yml_path=None, instance_start_delay=5):
+def run_xlsx_config(config_xlsx_path, sheet=None, variables_xlsx_path=None, variables_sheet=None, instance_start_delay=5):
     worksheet = get_worksheet(config_xlsx_path, sheet)
     xlsxdata = get_cells(worksheet, only_data=True)
     config = {}
@@ -18,16 +18,22 @@ def run_xlsx_config(config_xlsx_path, sheet=None, variables_yml_path=None, insta
     config["width"] = xlsxdata[2][1]
     config["height"] = xlsxdata[3][1]
     config["commands"] = xlsxdata[CMD_STARTING_ROW:]
-    if variables_yml_path:
-        with open(variables_yml_path, "r", encoding="utf-8") as fobj:
-            context = yaml.safe_load(fobj)
+    if variables_xlsx_path:
+        variables = []
+        variables_worksheet = get_worksheet(variables_xlsx_path, variables_sheet)
+        variables_table = get_cells(variables_worksheet, only_data=True)
+        header = variables_table[0]
+        for row_index in range(1, len(variables_table)):
+            row = {}
+            for col_index in range(len(variables_table[row_index])):
+                row[header[col_index]] = variables_table[row_index][col_index]
+            variables.append(row)
     else:
-        context = {}
-    if isinstance(context, (tuple, set, list)):
-        contexts = context
+        variables = []
+    if len(variables) > 1:
         browsers = []
         threads = []
-        for context in contexts:
+        for context in variables:
             browser = Browser(config)
             thread = threading.Thread(target=browser.run, args=[context])
             thread.setDaemon(True)
@@ -39,4 +45,4 @@ def run_xlsx_config(config_xlsx_path, sheet=None, variables_yml_path=None, insta
             thread.join()
     else:
         browser = Browser(config)
-        browser.run(context)
+        browser.run(variables[0])
